.. _tutorials-django:

=======================
Django with Pulsar
=======================

The code for this example is located in the :mod:`examples.djchat.manage`
module.

.. automodule:: examples.djchat.manage
